@@ -1353,7 +1353,7 @@ func (cli *VanClient) GatewayRemove(ctx context.Context, gatewayName string) err
 	}
 
 	if len(errs) > 0 {
-		return fmt.Errorf(strings.Join(errs, ","))
+		return fmt.Errorf("%s", strings.Join(errs, ","))
 	} else {
 		return nil
 	}
