@@ -140,7 +140,7 @@ type BindOptions struct {
 }
 
 func SkupperNotInstalledError(namespace string) error {
-	return fmt.Errorf("Skupper is not installed in Namespace: '%s`", namespace)
+	return fmt.Errorf("Skupper is not installed in Namespace: %s", namespace)
 
 }
 
@@ -160,7 +160,7 @@ func parseTargetTypeAndName(args []string) (string, string) {
 }
 
 func configureHeadlessProxy(spec *types.Headless, options *types.Tuning) error {
-	var err error
+	var errOut error
 	if options.Affinity != "" {
 		spec.Affinity = utils.LabelToMap(options.Affinity)
 	}
@@ -175,7 +175,7 @@ func configureHeadlessProxy(spec *types.Headless, options *types.Tuning) error {
 		if err == nil {
 			spec.CpuRequest = &cpuQuantity
 		} else {
-			err = fmt.Errorf("Invalid value for cpu: %s", err)
+			errOut = fmt.Errorf("invalid value for cpu: %s", err)
 		}
 	}
 	if options.Memory != "" {
@@ -183,7 +183,7 @@ func configureHeadlessProxy(spec *types.Headless, options *types.Tuning) error {
 		if err == nil {
 			spec.MemoryRequest = &memoryQuantity
 		} else {
-			err = fmt.Errorf("Invalid value for memory: %s", err)
+			errOut = fmt.Errorf("invalid value for memory: %s", err)
 		}
 	}
 	if options.CpuLimit != "" {
@@ -191,7 +191,7 @@ func configureHeadlessProxy(spec *types.Headless, options *types.Tuning) error {
 		if err == nil {
 			spec.CpuLimit = &cpuQuantity
 		} else {
-			err = fmt.Errorf("Invalid value for cpu: %s", err)
+			errOut = fmt.Errorf("invalid value for cpu: %s", err)
 		}
 	}
 	if options.MemoryLimit != "" {
@@ -199,10 +199,10 @@ func configureHeadlessProxy(spec *types.Headless, options *types.Tuning) error {
 		if err == nil {
 			spec.MemoryLimit = &memoryQuantity
 		} else {
-			err = fmt.Errorf("Invalid value for memory: %s", err)
+			errOut = fmt.Errorf("invalid value for memory: %s", err)
 		}
 	}
-	return err
+	return errOut
 }
 
 func expose(cli types.VanClientInterface, ctx context.Context, targetType string, targetName string, options ExposeOptions) (string, error) {
@@ -228,7 +228,7 @@ func expose(cli types.VanClientInterface, ctx context.Context, targetType string
 	if service == nil {
 		if options.Headless {
 			if targetType != "statefulset" {
-				return "", fmt.Errorf("The headless option is only supported for statefulsets")
+				return "", fmt.Errorf("the headless option is only supported for statefulsets")
 			}
 			service, err = cli.GetHeadlessServiceConfiguration(targetName, options.Protocol, options.Address, options.Ports, options.PublishNotReadyAddresses, options.Namespace)
 			if err != nil {
@@ -387,14 +387,18 @@ func NewClientHandleError(namespace string, context string, kubeConfigPath strin
 var routerCreateOpts types.SiteConfigSpec
 var routerLogging string
 
-func asMap(entries []string) map[string]string {
+func asMap(entries string) map[string]string {
 	result := map[string]string{}
-	for _, entry := range entries {
-		parts := strings.Split(entry, "=")
-		if len(parts) > 1 {
-			result[parts[0]] = parts[1]
-		} else {
-			result[parts[0]] = ""
+	if entries != "" {
+		separator := routerCreateOpts.AnnotationSeparator
+		annotations := strings.SplitAfter(entries, separator)
+		for _, entry := range annotations {
+			parts := strings.SplitAfterN(entry, "=", 2)
+			if len(parts) > 1 {
+				result[strings.TrimSuffix(parts[0], "=")] = strings.TrimSuffix(parts[1], separator)
+			} else {
+				result[parts[0]] = ""
+			}
 		}
 	}
 	return result
@@ -404,7 +408,7 @@ var LoadBalancerTimeout time.Duration
 
 type InitFlags struct {
 	routerMode string
-	labels     []string
+	labels     string
 }
 
 var initFlags InitFlags
@@ -474,7 +478,7 @@ installation that can then be connected to other skupper installations`,
 	cmd.Flags().StringVarP(&routerCreateOpts.Ingress, "ingress", "", "", "Setup Skupper ingress to one of: ["+strings.Join(types.ValidIngressOptions(platform), "|")+"].")
 	cmd.Flags().StringVarP(&initFlags.routerMode, "router-mode", "", string(types.TransportModeInterior), "Skupper router-mode")
 
-	cmd.Flags().StringSliceVar(&initFlags.labels, "labels", []string{}, "Labels to add to resources created by skupper")
+	cmd.Flags().StringVar(&initFlags.labels, "labels", "", "Labels to add to resources created by skupper")
 	cmd.Flags().StringVarP(&routerLogging, "router-logging", "", "", "Logging settings for router. 'trace', 'debug', 'info' (default), 'notice', 'warning', and 'error' are valid values.")
 
 	cmd.Flags().StringVarP(&routerCreateOpts.PrometheusServer.ExternalServer, "external-prometheus-server", "", "", "External prometheus server for metric aggregation. Valid only when --enable-flow-collector")
